import logging

from django.core.management.base import (BaseCommand, CommandParser,
                                         CommandError)
from django.core.mail import EmailMessage
from botocore.exceptions import ClientError

logger = logging.getLogger('dict_config_logger')


def get_sender_email():
    """Getting sender email id"""

    sender_email_configuration = SenderEmailConfiguration.objects.first()
    if sender_email_configuration:
        sender = sender_email_configuration.sender_email_address
    else:
        sender = None
    return sender


def send_log_email(email_type):
    """ function to send emails of log file to personas"""

    # Replace sender@example.com with your "From" address.
    # This address must be verified with Amazon SES.
    SENDER = email_type.sender

    # Replace recipient@example.com with a "To" address. If your account
    # is still in the sandbox, this address must be verified.
    RECIPIENT = list(email_type.recipients.values_list("email_address",
                                                       flat=True))

    # The subject line for the email.
    SUBJECT = email_type.subject

    # The HTML body of the email.
    BODY_HTML = email_type.template_type.template_body

    for each_recipient in RECIPIENT:
        try:
            # Provide the contents of the email.
            mail = EmailMessage(SUBJECT, BODY_HTML, SENDER,
                                [each_recipient])
            mail.content_subtype = "html"

            # mail.send()
        # Display an error if something goes wrong.
        except ClientError as e:
            logger.error(e.response['Error']['Message'])
            continue

    # body_data = EmailSerializer(email_type).data

    # body_data["template_inputs"] = template_inputs
    # body_data = json.dumps(body_data)

    # headers = {'Content-Type': 'application/json'}

    # jar = requests.cookies.RequestsCookieJar()
    # jar.set('__Host-p1ps-staging-authservice-session-id-cookie',
    #         'NlnUUosv8pQF85lKSwoFfVUjwbqy57Uskh1Mt9JJJ9pfwxqjk0h98tFooSfdvRvk',
    #         domain='p1ps-il2.staging.dso.mil', path='/')

    # P1_response = requests.post(url='https://p1ps-il2.staging.dso.mil/api/teams/IPKRGXU5RFEUNPJSNXWBGBSBNE/emails/edlm-status-update',
    #                             data=body_data, headers=headers,
    #                             auth=TokenAuth(), cookies=jar)

    # print(P1_response.text)


class Command(BaseCommand):
    """Django command to send an emails to the filer/personas, when the log
    warning/error occurred in the metadata EVTVL process."""

    def handle(self, *args, **options):
        """Email log notification is sent to filer/personas when warning/error
        occurred in EVTVL process"""
        send_log_email()



import json
import logging

import requests

from requests.auth import AuthBase

from django.core.management.base import (BaseCommand, CommandParser,
                                         CommandError)
from django.core.mail import EmailMessage
from botocore.exceptions import ClientError

from openlxp_notifications.models import (email)

from openlxp_notifications.serializer import EmailSerializer

logger = logging.getLogger('dict_config_logger')

"""
    Requests set up to verify using AWS Simple Email Service (SES)

"""


def SendResponse(response):
    """Function to return response and error catches"""

    if response.status_code in [400, 401, 404, 500]:
        logger.error(response.json())
        return False
    elif response.status_code in [200, 201]:
        try:
            logger.info(response.json())
        except requests.RequestException:
            logger.warning(requests.RequestException)
        return True


"""
    Requests set up using AWS Simple Email Service (SES)

"""


def send_email(body_data, template_type):
    """Request to send email via P1PS"""

    # Check user Permissions to use team

    base_endpoint = get_SES_base_endpoint()
    # team_id = get_P1PS_team_ID()

    url = base_endpoint + "/api/teams/" + team_id + "/emails/" + template_type

    response = requests.post(url=url, headers=headers,
                             data=body_data, auth=TokenAuth(),
                             cookies=SetCookies())
    SendResponse(response)